import { PureComponent, ReactNode } from 'react';
import { ThemeProps } from '@atlaskit/theme/types';
import { SupportedLanguages } from '../supportedLanguages';
import { Theme } from '../themes/themeBuilder';
export interface CodeProps {
    /** The style object to apply to code */
    codeStyle?: {};
    /** The element or custom react component to use in place of the default code tag */
    codeTagProps?: {};
    /** The language in which the code is written */
    language: SupportedLanguages | string;
    /** The style object to apply to the container that shows line number */
    lineNumberContainerStyle?: {};
    /** The element or custom react component to use in place of the default span tag */
    preTag?: ReactNode | string;
    /** Indicates whether or not to show line numbers */
    showLineNumbers?: boolean;
    /** The code to be formatted */
    text: string;
    /** A custom theme to be applied, implements the Theme interface */
    theme?: Theme | ThemeProps;
    /**
     * Lines to highlight comma delimited.
     * Example uses:
  
     * - To highlight one line `highlight="3"`
     * - To highlight a group of lines `highlight="1-5"`
     * - To highlight multiple groups `highlight="1-5,7,10,15-20"`
     */
    highlight?: string;
}
export default class Code extends PureComponent<CodeProps, {}> {
    static defaultProps: {
        theme: {};
        showLineNumbers: boolean;
        lineNumberContainerStyle: {};
        codeTagProps: {};
        preTag: string;
        highlight: string;
    };
    getLineOpacity(lineNumber: number): 1 | 0.3;
    render(): JSX.Element;
}
